@@ -78,6 +78,25 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */
 #define UC_MCONTEXT_FPOWNED_FPU 0x20001
 #define UC_MCONTEXT_FPFMT_XMM   0x10002
 #define UC_MCONTEXT_MC_LEN_VAL  0x320
+#elif defined(__QNX__)
+#define UC_SIGMASK              0x0
+#define UC_MCONTEXT_GREGS_R8    0x48
+#define UC_MCONTEXT_GREGS_R9    0x50
+#define UC_MCONTEXT_GREGS_R10   0x40
+#define UC_MCONTEXT_GREGS_R11   0x78
+#define UC_MCONTEXT_GREGS_R12   0x80
+#define UC_MCONTEXT_GREGS_R13   0x88
+#define UC_MCONTEXT_GREGS_R14   0x90
+#define UC_MCONTEXT_GREGS_R15   0x98
+#define UC_MCONTEXT_GREGS_RDI   0x28
+#define UC_MCONTEXT_GREGS_RSI   0x30
+#define UC_MCONTEXT_GREGS_RBP   0x68
+#define UC_MCONTEXT_GREGS_RBX   0x60
+#define UC_MCONTEXT_GREGS_RDX   0x38
+#define UC_MCONTEXT_GREGS_RAX   0x58
+#define UC_MCONTEXT_GREGS_RCX   0x70
+#define UC_MCONTEXT_GREGS_RSP   0xb8
+#define UC_MCONTEXT_GREGS_RIP   0xa0
 #elif defined __sun
 #define UC_MCONTEXT_GREGS_R8	0x78
 #define UC_MCONTEXT_GREGS_R9	0x70
